<?php

	/*
	 * To change this license header, choose License Headers in Project Properties.
	 * To change this template file, choose Tools | Templates
	 * and open the template in the editor.
	 */

	/**
	 * Description of VebraImportShell
	 *
	 * @author Luke
	 */
	class VebraImportShell extends AppShell {

		public $uses = array('Vebra.Branch', 'Vebra.Property', 'Vebra.Paragraph', 'EvCore.Image');

		public function main() {
			// Change settings for file uploads to avoid potential issues
			ini_set('upload_max_filesize', '5M');
			ini_set('max_file_uploads', '5000');

			// Import the branches
			$this->dispatchShell('vebra_import import_branches');

			// For each branch now stored in the database, get it's properties
			foreach ($this->Branch->find('all') as $branch) {
				$this->dispatchShell('vebra_import import_properties ' . $branch['Branch']['branchid']);
			}
		}

		public function import_branches() {
			$added = $updated = $affected = $failed = 0;
			foreach ($this->Branch->getVebraBranches() as $branch) {
				try {
					$existing_branch = $this->Branch->find('first', array('conditions' => array('Branch.branchid' => $branch['branchid'])));
					if ($existing_branch) {
						$this->Branch->set('id', $existing_branch['Branch']['id']);
						$updated++;
					} else {
						$this->Branch->create();
						$added++;
					}
					$this->Branch->save($branch);
					$affected++;
				} catch (Exception $e) {
					$failed++;
					if ($existing_branch) {
						$updated--;
					} else {
						$added--;
					}
					$this->out('<error>' . $e->getMessage() . '</error>');
				}
			}
			$this->out("$affected affected ($added added, $updated updated, $failed failed)");
		}

		public function import_properties() {
			$added = $updated = $affected = $failed = 0;
			if (isset($this->args[0])) {
				$branch_id = $this->args[0];
				$properties = $this->Property->getVebraProperties($branch_id);
				if (!empty($properties)) {
					foreach ($properties as $property) {
						try {
							$existing_property = $this->Property->find('first', array('conditions' => array('Property.id' => $property['Property']['id'])));
							if ($existing_property) {
								$property['Property']['id'] = $existing_property['Property']['id']; // this doesn't make much difference, as property id will be the same as the existing property id
								$this->Image->deleteAll(array(
									'model' => 'Property',
									'model_id' => $property['Property']['id']
								)); // delete all images if we already have the property (so that they can be re-imported)
								$this->Paragraph->deleteAll(array(
									'property_id' => $property['Property']['id']
								)); // delete all images if we already have the property (so that they can be re-imported)
								$updated++;
							} else {
								$this->Property->create();
								$added++;
							}

							// Save properties
							$this->Property->saveAssociated($property);
							$affected++;
						} catch (Exception $e) {
							$failed++;
							if ($existing_property) {
								$updated--;
							} else {
								$added--;
							}
							$this->out('<error>' . $e->getMessage() . '</error>');
						}
					}
				}
			} else {
				$this->out('<error>No branch ID specified when attemtping to import properties</error>');
			}
			$this->out("$affected affected ($added added, $updated updated, $failed failed)");
		}

		public function import_updated_properties() {
			$this->out('This doesn\'t actually do anything... yet');
		}

	}
